aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--epan/dissectors/packet-wccp.c4
-rw-r--r--epan/dissectors/packet-wccp.h2
2 files changed, 3 insertions, 3 deletions
diff --git a/epan/dissectors/packet-wccp.h b/epan/dissectors/packet-wccp.h
index d2f23b1d2b..f6b9b3131e 100644
--- a/epan/dissectors/packet-wccp.h
+++ b/epan/dissectors/packet-wccp.h
@@ -1,5 +1,5 @@
/* packet-wccp.h
- * Declarations for Cisco Web Cache Coordination Protocol
+ * Declarations for Cisco Web Cache Communication Protocol
*
* $Id$
*
diff --git a/epan/dissectors/packet-wccp.c b/epan/dissectors/packet-wccp.c
index cdfa53d851..f971a2037d 100644
--- a/epan/dissectors/packet-wccp.c
+++ b/epan/dissectors/packet-wccp.c
@@ -1,5 +1,5 @@
/* packet-wccp.c
* Routines for Web Cache Coordination Protocol dissection
* Jerry Talkington <jtalkington@users.sourceforge.net>
*
* $Id$
@@ -1446,7 +1446,7 @@ proto_register_wccp(void)
&ett_unknown_info,
};
- proto_wccp = proto_register_protocol("Web Cache Coordination Protocol",
+ proto_wccp = proto_register_protocol("Web Cache Communication Protocol",
"WCCP", "wccp");
proto_register_field_array(proto_wccp, hf, array_length(hf));
proto_register_subtree_array(ett, array_length(ett));
@@ -1,5 +1,5 @@
/* packet-wccp.c
- * Routines for Web Cache Coordination Protocol dissection
+ * Routines for Web Cache Communication Protocol dissection
* Jerry Talkington <jtalkington@users.sourceforge.net>
*